source("readin.Rinclude")

d <-  subset(d, d$DRlag>0.01)

yl100 <-  yl*100

plot.surv.text <-  function() { text(-xl+0.5, -yl100, "(More\nSurvivorship\nBias)", pos=3) }

################################################################
## let's thin one figure
################################################################
{
  e <-  subset( d, select=c( logr.x, dca.w ) )
  f <-  e;  f$logr.x <- c(NA); f$dca.w <- c(NA);

  for (lower in seq(-1,1,by=0.1)) {
    range.e <-  subset( e, (e$logr.x>lower) & (e$logr.x<lower+0.1) )
    range.e1000 <-  range.e[as.integer(runif(1000, min=1, max=nrow(range.e))),]
    f <-  rbind( f, range.e1000)
  }

  pdf.start("logr-dca-w-pruned-wide", wd=12)  
  plot( f$logr.x, f$dca.w*100, xlab="Log Stock Return", ylab="DCA (Managerial Change in D/C), in %",
       ylim=c(-yl100,yl100), pch=".", type="p")
  hline(0)
  plot.surv.text()
  pdf.end()

  pdf.start("logr-dca-w-pruned")  
  plot( f$logr.x, f$dca.w*100, xlab="Log Stock Return", ylab="DCA (Managerial Change in D/C), in %",
       ylim=c(-yl100,yl100), pch=".", type="p")
  hline(0)
  plot.surv.text()
  pdf.end()
}


################################################################
### Shock Graphs
################################################################

pdf.start("logr-dct")
plot( d$logr.x, d$dct*100, xlab="Log Stock Return", ylab="DCT (Total Change in D/C), in %",
     ylim=c(-yl100,yl100), pch=".", type="p", col="blue")
#hline(0)
plot.surv.text()
pdf.end()

pdf.start("logr-dcp")
plot( d$logr.x, d$dcp*100, xlab="Log Stock Return", ylab="DCP (Return-Induced Change in D/C), in %",
     ylim=c(-yl100,yl100), pch=".", type="p", col="blue")
hline(0)
plot.surv.text()
pdf.end()

pdf.start("logr-dca-x")
plot( d$logr.w, d$dca.x*100, xlab="Log Stock Return (w/Div)", ylab="DCA (Managerial Change in D/C, w/Div), in %",
     ylim=c(-yl100,yl100), pch=".", type="p")
hline(0)
plot.surv.text()
pdf.end()


pdf.start("logr-dca-w")
plot( d$logr.x, d$dca.w*100, xlab="Log Stock Return", ylab="DCA (Managerial Change in D/C), in %",
     ylim=c(-yl100,yl100), pch=".", type="p")
hline(0)
plot.surv.text()
pdf.end()



################################################################
### Histograms Now #############################################
################################################################
################################################################
iaw.hist  <-  function( fname, xseries, xlim, xlab, ... ) {
  a <- hist( xseries, breaks= breakseq, plot=F)

  pdf.start(fname)
  a$counts[ a$counts==0 ] <-  NA  # omit the exact zeros;  irrelevant now;
  plot( a$mids, a$counts, xlim=xlim, xlab=xlab, ylab="", type="h", ...)
}

################################################################
my.limit <- 100
my.step <- 0.1

breakseq <- c(-1000, seq( from= -1*my.limit-my.step/2, to= my.limit+my.step/2, by=my.step), 1000)

iaw.hist("hist-dca-w" , 100*d$dca.w, c(-50, 50 ), "DCA (Managerial Change in D/C)")
text( -52, 200, "My Truncation (Mass < -50%)", srt=90, pos=4 )
text( 48, 200, "My Truncation  (Mass > +50%)", srt=90, pos=4 )
pdf.end()

iaw.hist("hist-dca-w-zoom", 100*d$dca.w, c(-10,10), "DCA (Managerial Change in D/C)")
pdf.end()
